# TestUmbrella v1.0.3

**Project**: TestUmbrella
<br>**Version**: 1.0.3
<br>**OS**: OS Independent
<br>**Author**: Irakli Gzirishvili
<br>**Mail**: gziraklirex@gmail.com

**TestUmbrella** is a Python command-line interface application. Test umbrella project

## Installation

To use **TestUmbrella**, follow these steps:

- Open CMD and run the following command to install `pip install testumbrella` then restart your CMD
- To check if **TestUmbrella** is installed correctly, run the following command `testumbrella`

## Commands

These are the available commands you can use:

- `testumbrella` - To list available commands
- `testumbrella demo (param)` - Test demo method with param